@@ -25,6 +25,12 @@
 #include "funcions.h"
 #include "moviment.h"
 
+/*
+  * Per actualitzar les cadenes de traducció
+  * lupdate -verbose peg-solitaire.pro
+  * al terminal
+  */
+
 extern QTranslator *qt_translator;
 extern QTranslator *appTranslator;
 
@@ -65,6 +71,8 @@ frmPrincipal::frmPrincipal()
   setWindowTitle( tr("Solitari"));
   setMinimumSize (QSize(600,380));
   this->move(300,100);
+  //Recuperam les dimensions del formulari
+  restoreGeometry(QSettings().value(QString("General/geometry")).toByteArray());
 
    jocFram=new QFrame(this);
    jocFram->setGeometry(0,alcadaMenuBarraTasques,300,300);
@@ -84,7 +92,7 @@ frmPrincipal::frmPrincipal()
     tabArbres->move(QPoint(0,50));
     //arbre de figures
     arbreModalitatsJocTreeWidget= new QTreeWidget(jocFram);
-    arbreModalitatsJocTreeWidget->setMinimumSize(QSize(280,220));
+    arbreModalitatsJocTreeWidget->setMinimumSize(QSize(280,210));
    // arbreModalitatsJocTreeWidget->move(QPoint(0,70));
     arbreModalitatsJocTreeWidget->expandAll();
    // connect(arbreModalitatsJocTreeWidget,SIGNAL(itemClicked(QTreeWidgetItem*, int)),
@@ -164,7 +172,7 @@ void frmPrincipal::carregaArbreModalitatsJoc(){
 //Cadenes amb els noms de les modalitats de joc per a la traducció
 //El codi de joc de data.sol cal que coincideixi amb l'index a l'array
 //El primer és el ròtul de l'arbre amb les modalitats del joc
-    static const char * const nomModalitatsJoc[] = {
+    static const char *const nomModalitatsJoc[] = {
         QT_TR_NOOP("Modalitats del joc"),
         QT_TR_NOOP("Clàssic"),
         QT_TR_NOOP("Clàssic-simetria"),
@@ -202,7 +210,7 @@ void frmPrincipal::carregaArbreModalitatsJoc(){
         QT_TR_NOOP("Quadrat 5x5-central"),
         QT_TR_NOOP("Quadrat 5x5-H"),
         QT_TR_NOOP("Wiegleb"),
-        QT_TR_NOOP("Diamant 9x9"),
+        QT_TR_NOOP("Diamant diagonal 9x9- 1"),
         QT_TR_NOOP("Europeu-creu"),
         QT_TR_NOOP("Wiegleb-clàssic"),
         QT_TR_NOOP("Clàssic- 6"),
@@ -227,7 +235,7 @@ void frmPrincipal::carregaArbreModalitatsJoc(){
         QT_TR_NOOP("Clàssic- 10"),
         QT_TR_NOOP("Clàssic-R"),
         QT_TR_NOOP("Clàssic-T"),
-        QT_TR_NOOP("Diamant 9x9- 1"),
+        QT_TR_NOOP("Diamant diagonal 9x9- 2"),
         QT_TR_NOOP("Solitari 5x6- 1"),
         QT_TR_NOOP("Quadrat 6x6- 1"),
         QT_TR_NOOP("Quadrat 5x5- 2"),
@@ -280,7 +288,7 @@ void frmPrincipal::carregaArbreModalitatsJoc(){
         QT_TR_NOOP("Quadrat 5x5- 3"),
         QT_TR_NOOP("Triangular 10"),
         QT_TR_NOOP("Quadrat 8x8"),
-        QT_TR_NOOP("Diamant 9x9- 2"),
+        QT_TR_NOOP("Diamant diagonal 9x9- 3"),
         QT_TR_NOOP("Clàssic- 12"),
         QT_TR_NOOP("Europeu- 4"),
         QT_TR_NOOP("Clàssic- 13"),
@@ -309,7 +317,32 @@ void frmPrincipal::carregaArbreModalitatsJoc(){
         QT_TR_NOOP("Clàssic - 29"),
         QT_TR_NOOP("Clàssic - 30"),
         QT_TR_NOOP("Clàssic - 31"),
-        QT_TR_NOOP("Clàssic ampliat"),
+        //nous versió 1.2
+        QT_TR_NOOP("Dos quadrats 10x10 - 1"),
+        QT_TR_NOOP("Dos quadrats 11x11 - 1"),
+        QT_TR_NOOP("Tres quadrats 16x16 - 1"),
+        QT_TR_NOOP("Dos quadrats 9x9 - 1"),
+        QT_TR_NOOP("Tres quadrats 13x13 - 1"),
+        QT_TR_NOOP("Quatre quadrats 13x13 - 1"),
+        QT_TR_NOOP("Europeu- 2"),
+        QT_TR_NOOP("Clàssic ampliat- 1"),
+        QT_TR_NOOP("Clàssic ampliat- 2"),
+        QT_TR_NOOP("Diamant diagonal 9x9- 4"),
+        QT_TR_NOOP("Diamant 9x9- 1"),
+        QT_TR_NOOP("Diamant 9x9- 2"),
+        QT_TR_NOOP("Diamant 9x9- 3"),
+        QT_TR_NOOP("Rombe 36- 1"),
+        QT_TR_NOOP("Rombe 36- 2"),
+        QT_TR_NOOP("Rombe 36- 3"),
+        QT_TR_NOOP("Rombe 36- 4"),
+        QT_TR_NOOP("Diamant 9x9- 4"),
+        QT_TR_NOOP("Diamant 9x9- 5"),
+        QT_TR_NOOP("Diamant 9x9- 6"),
+        QT_TR_NOOP("Diamant 9x9- 7"),
+        QT_TR_NOOP("Diamant 9x9- 8"),
+        QT_TR_NOOP("Diamant 9x9- 9"),
+        QT_TR_NOOP("Diamant 9x9- 10"),
+       // QT_TR_NOOP("Clàssic ampliat"), //no està activat
         0
     };
 
@@ -710,6 +743,11 @@ void frmPrincipal::resizeEvent ( QResizeEvent * event ){
 void frmPrincipal::closeEvent(QCloseEvent* event){
    QStringList  tipusJoc =   arbreModalitatsJocTreeWidget->selectedItems().first()->text(1).split(" ");
    QSettings().setValue("General/modalidadJoc",tipusJoc.value(0));
+   /*12/03/12
+     Desam la disposició del formulari
+     */
+   QSettings().setValue(QString("General/geometry"),saveGeometry());
+   event->accept();
 }
 
 void frmPrincipal::creditsProgramaSlot(){
