@@ -236,9 +236,14 @@ void Tauler::joc_CarregaJoc( QString p_tipusJoc, QString p_filesColumnes, QStrin
     int contador=0;
     for(int j=0 ; j<files;++j){
                for(int i=0; i<j;++i){
+                   //Afegit el if pel solitari tipus Rombe
+                   if (estatFitxes.value(contador).toInt()>-1){
                        QPoint coord(j-1,i); //fila i columna
                        Fitxa *fitxa= new Fitxa(this);
                        fitxa->setEstat(estatFitxes.value(contador).toInt());
+                      /* qCritical("%s", qPrintable(QString("Contador %1 estatFitxa %2")
+                                                  .arg(contador)
+                                                  .arg(estatFitxes.value(contador).toInt())));*/
                        fitxa->setTipusMoviment(tipusJoc.value(1).toInt());
                        fitxa->setCoordenades(coord);
                        fitxa->setPos( fitxa->coordenades().y()*distanciaEntreFitxes*30-15*1.2*j,
@@ -248,7 +253,8 @@ void Tauler::joc_CarregaJoc( QString p_tipusJoc, QString p_filesColumnes, QStrin
                      //  qDebug("fitxa %d,%d",fitxa->pos().x(),fitxa->pos().y());
                        m_fitxes.insert(coord.x()*100+coord.y(),fitxa);
                        scene()->addItem(fitxa);
-                       if (fitxa->estat()==1) {++comptadorFitxesJoc;}
+                       if (fitxa->estat() == 1) {++comptadorFitxesJoc;}
+                        }//if estat fitxa
                        ++contador;
                } //for columnes
            }//for files
